// SPDX-License-Identifier: MIT

use axum::{response::IntoResponse, routing::post, Router};

use crate::common::{exec_command, CheckAuthRestApi, RestApiPermissionAbosWebRestart};
use crate::error::ErrorStringResult;

pub fn routes() -> Router {
    Router::new().route("/api/abosweb/restart", post(restapi_abosweb_restart))
}

/// POST "/api/abosweb/restart"
/// Access: AbosWebRestart
/// Input: None
/// Output: connection reset. (abos-web is stopped before returning a response)
async fn restapi_abosweb_restart(
    _auth: CheckAuthRestApi<RestApiPermissionAbosWebRestart>,
) -> ErrorStringResult {
    exec_command(&["abosweb_restart.sh"]).await?;
    Ok(().into_response())
}
